@@ -1,9 +1,11 @@
 import os
 import os.path
+
 import yaml
-from sdcclient import SdSecureClient, SdScanningClient, SdSecureClientV1
-from sdcclient import SdMonitorClient as SdMonitorClientV2
 from sdcclient import SdMonitorClient
+from sdcclient import SdMonitorClient as SdMonitorClientV2
+from sdcclient import SdSecureClient, SdScanningClient, SdSecureClientV1
+from sdcclient.monitor import EventsClientV1
 
 from sdccli.cli.formatter.json_formatter import JsonFormatter
 from sdccli.cli.formatter.text_formatter import NormalFormatter
@@ -97,6 +99,14 @@ class Config(object):
             import urllib3
             urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
+    @property
+    def events_client_v1(self):
+        return EventsClientV1(
+            token=self.monitor["token"],
+            sdc_url=self.monitor["url"],
+            ssl_verify=self.monitor["ssl_verify"]
+        )
+
     @property
     def sdmonitor(self):
         return SdMonitorClient(
